@@ -1,6 +1,6 @@
 package WWW::Google::Contacts;
 {
-    $WWW::Google::Contacts::VERSION = '0.38';
+    $WWW::Google::Contacts::VERSION = '0.39';
 }
 
 # ABSTRACT: Google Contacts Data API
@@ -276,6 +276,17 @@ __PACKAGE__->meta->make_immutable;
 1;
 __END__
 
+=head1 NAME
+
+WWW::Google::Contacts - Google Contacts Data API
+
+=head1 CURRENTLY NOT WORKING
+
+This module is currently not working. Some time back, Google obsoleted the authentication method
+used by this module.
+
+Patches for updating how authentication is handled are more than welcome!
+
 =head1 SYNOPSIS
 
     use WWW::Google::Contacts;
