@@ -1,6 +1,6 @@
 package WWW::Google::Contacts::Types;
 {
-    $WWW::Google::Contacts::Types::VERSION = '0.38';
+    $WWW::Google::Contacts::Types::VERSION = '0.39';
 }
 
 use MooseX::Types -declare => [
@@ -62,7 +62,7 @@ class_type Group, { class => 'WWW::Google::Contacts::Group' };
 
 coerce Group, from HashRef, via {
     require WWW::Google::Contacts::Group;
-    WWW::Google::Contacts::Group->new($_);
+    WWW::Google::Contacts::Group->new($_)
 };
 
 class_type Category, { class => 'WWW::Google::Contacts::Type::Category' };
@@ -93,7 +93,7 @@ coerce PhoneNumber,
 subtype ArrayRefOfPhoneNumber, as ArrayRef [PhoneNumber];
 
 coerce ArrayRefOfPhoneNumber, from ArrayRef, via {
-    return [ map { to_PhoneNumber($_) } @{$_} ];
+    return [ map { to_PhoneNumber($_) } @{$_} ]
 }, from Any, via { return [ to_PhoneNumber($_) ] };
 
 class_type Email, { class => 'WWW::Google::Contacts::Type::Email' };
@@ -107,7 +107,7 @@ coerce Email,
 subtype ArrayRefOfEmail, as ArrayRef [Email];
 
 coerce ArrayRefOfEmail, from ArrayRef, via {
-    [ map { to_Email($_) } @{$_} ];
+    [ map { to_Email($_) } @{$_} ]
 }, from Any, via { [ to_Email($_) ] };
 
 class_type IM, { class => 'WWW::Google::Contacts::Type::IM' };
@@ -121,7 +121,7 @@ coerce IM,
 subtype ArrayRefOfIM, as ArrayRef [IM];
 
 coerce ArrayRefOfIM, from ArrayRef, via {
-    [ map { to_IM($_) } @{$_} ];
+    [ map { to_IM($_) } @{$_} ]
 }, from Any, via { [ to_IM($_) ] };
 
 class_type Organization,
@@ -136,7 +136,7 @@ coerce Organization,
 subtype ArrayRefOfOrganization, as ArrayRef [Organization];
 
 coerce ArrayRefOfOrganization, from ArrayRef, via {
-    [ map { to_Organization($_) } @{$_} ];
+    [ map { to_Organization($_) } @{$_} ]
 }, from Any, via { [ to_Organization($_) ] };
 
 class_type PostalAddress,
@@ -151,7 +151,7 @@ coerce PostalAddress,
 subtype ArrayRefOfPostalAddress, as ArrayRef [PostalAddress];
 
 coerce ArrayRefOfPostalAddress, from ArrayRef, via {
-    [ map { to_PostalAddress($_) } @{$_} ];
+    [ map { to_PostalAddress($_) } @{$_} ]
 }, from Any, via { [ to_PostalAddress($_) ] };
 
 class_type Birthday, { class => 'WWW::Google::Contacts::Type::Birthday' };
@@ -171,13 +171,13 @@ coerce CalendarLink,
     WWW::Google::Contacts::Type::CalendarLink->new(
         type => "home",
         href => $_
-    );
+      )
   };
 
 subtype ArrayRefOfCalendarLink, as ArrayRef [CalendarLink];
 
 coerce ArrayRefOfCalendarLink, from ArrayRef, via {
-    [ map { to_CalendarLink($_) } @{$_} ];
+    [ map { to_CalendarLink($_) } @{$_} ]
 }, from Any, via { [ to_CalendarLink($_) ] };
 
 class_type ContactEvent,
@@ -190,7 +190,7 @@ coerce ContactEvent,
 subtype ArrayRefOfContactEvent, as ArrayRef [ContactEvent];
 
 coerce ArrayRefOfContactEvent, from ArrayRef, via {
-    [ map { to_ContactEvent($_) } @{$_} ];
+    [ map { to_ContactEvent($_) } @{$_} ]
 }, from Any, via { [ to_ContactEvent($_) ] };
 
 class_type ExternalId, { class => 'WWW::Google::Contacts::Type::ExternalId' };
@@ -202,7 +202,7 @@ coerce ExternalId,
 subtype ArrayRefOfExternalId, as ArrayRef [ExternalId];
 
 coerce ArrayRefOfExternalId, from ArrayRef, via {
-    [ map { to_ExternalId($_) } @{$_} ];
+    [ map { to_ExternalId($_) } @{$_} ]
 }, from Any, via { [ to_ExternalId($_) ] };
 
 class_type Gender, { class => 'WWW::Google::Contacts::Type::Gender' };
@@ -227,7 +227,7 @@ coerce GroupMembership,
 subtype ArrayRefOfGroupMembership, as ArrayRef [GroupMembership];
 
 coerce ArrayRefOfGroupMembership, from ArrayRef, via {
-    [ map { to_GroupMembership($_) } @{$_} ];
+    [ map { to_GroupMembership($_) } @{$_} ]
 }, from Any, via { [ to_GroupMembership($_) ] };
 
 class_type Hobby, { class => 'WWW::Google::Contacts::Type::Hobby' };
@@ -241,7 +241,7 @@ coerce Hobby,
 subtype ArrayRefOfHobby, as ArrayRef [Hobby];
 
 coerce ArrayRefOfHobby, from ArrayRef, via {
-    [ map { to_Hobby($_) } @{$_} ];
+    [ map { to_Hobby($_) } @{$_} ]
 }, from Any, via { [ to_Hobby($_) ] };
 
 class_type Jot, { class => 'WWW::Google::Contacts::Type::Jot' };
@@ -255,7 +255,7 @@ coerce Jot,
 subtype ArrayRefOfJot, as ArrayRef [Jot];
 
 coerce ArrayRefOfJot, from ArrayRef, via {
-    [ map { to_Jot($_) } @{$_} ];
+    [ map { to_Jot($_) } @{$_} ]
 }, from Any, via { [ to_Jot($_) ] };
 
 class_type Language, { class => 'WWW::Google::Contacts::Type::Language' };
@@ -269,7 +269,7 @@ coerce Language,
 subtype ArrayRefOfLanguage, as ArrayRef [Language];
 
 coerce ArrayRefOfLanguage, from ArrayRef, via {
-    [ map { to_Language($_) } @{$_} ];
+    [ map { to_Language($_) } @{$_} ]
 }, from Any, via { [ to_Language($_) ] };
 
 class_type Priority, { class => 'WWW::Google::Contacts::Type::Priority' };
@@ -291,7 +291,7 @@ coerce Relation,
 subtype ArrayRefOfRelation, as ArrayRef [Relation];
 
 coerce ArrayRefOfRelation, from ArrayRef, via {
-    [ map { to_Relation($_) } @{$_} ];
+    [ map { to_Relation($_) } @{$_} ]
 }, from Any, via { [ to_Relation($_) ] };
 
 class_type UserDefined, { class => 'WWW::Google::Contacts::Type::UserDefined' };
@@ -303,12 +303,12 @@ coerce UserDefined,
 subtype ArrayRefOfUserDefined, as ArrayRef [UserDefined];
 
 coerce ArrayRefOfUserDefined, from ArrayRef, via {
-    [ map { to_UserDefined($_) } @{$_} ];
+    [ map { to_UserDefined($_) } @{$_} ]
 }, from HashRef, via {
     my $ref = $_;
     return [ to_UserDefined($ref) ] if ( defined $ref->{key} );
     [ map { to_UserDefined( { key => $_, value => $ref->{$_}{value} } ) }
-          keys %{$ref} ];
+          keys %{$ref} ]
 }, from Any, via { [ to_UserDefined($_) ] };
 
 class_type Website, { class => 'WWW::Google::Contacts::Type::Website' };
@@ -316,13 +316,13 @@ class_type Website, { class => 'WWW::Google::Contacts::Type::Website' };
 coerce Website,
   from HashRef,
   via { WWW::Google::Contacts::Type::Website->new($_) }, from Str, via {
-    WWW::Google::Contacts::Type::Website->new( type => "home", value => $_ );
+    WWW::Google::Contacts::Type::Website->new( type => "home", value => $_ )
   };
 
 subtype ArrayRefOfWebsite, as ArrayRef [Website];
 
 coerce ArrayRefOfWebsite, from ArrayRef, via {
-    [ map { to_Website($_) } @{$_} ];
+    [ map { to_Website($_) } @{$_} ]
 }, from Any, via { [ to_Website($_) ] };
 
 class_type Sensitivity, { class => 'WWW::Google::Contacts::Type::Sensitivity' };
@@ -337,5 +337,5 @@ class_type Photo, { class => 'WWW::Google::Contacts::Photo' };
 
 coerce Photo, from HashRef, via {
     require WWW::Google::Contacts::Photo;
-    WWW::Google::Contacts::Photo->new($_);
+    WWW::Google::Contacts::Photo->new($_)
 };
